@@ -3,6 +3,6 @@ require( tcltk)
 require( ismev)
 extremes.gui()
 cat("\n", "Package extRemes: For a tutorial and more information go to", "\n")
-cat("http://www.esig.ucar.edu/extremevalues/evtk.html", "\n")
+cat("http://www.isse.ucar.edu/extremevalues/evtk.html", "\n")
 # write.extRemesMainMessage()
 } # end of '.First.lib' fcn
